@@ -108,7 +108,7 @@ impl PeerRegistry {
                 return Err(PeerError::ReachMaxOutboundLimit.into());
             }
         }
-        peer_store.add_connected_peer(remote_addr.clone(), session_type)?;
+        peer_store.add_connected_peer(remote_addr.clone(), session_type);
         let peer = Peer::new(session_id, session_type, remote_addr, is_whitelist);
         self.peers.insert(session_id, peer);
         Ok(evicted_peer)
@@ -145,13 +145,14 @@ impl PeerRegistry {
             &mut candidate_peers,
             EVICTION_PROTECT_PEERS,
             |peer1, peer2| {
+                let now = std::time::Instant::now();
                 let peer1_last_message = peer1
                     .last_ping_protocol_message_received_at
-                    .map(|t| t.elapsed().as_secs())
+                    .map(|t| now.saturating_duration_since(t).as_secs())
                     .unwrap_or_else(|| std::u64::MAX);
                 let peer2_last_message = peer2
                     .last_ping_protocol_message_received_at
-                    .map(|t| t.elapsed().as_secs())
+                    .map(|t| now.saturating_duration_since(t).as_secs())
                     .unwrap_or_else(|| std::u64::MAX);
                 peer2_last_message.cmp(&peer1_last_message)
             },
